@@ -13,7 +13,7 @@ test_that("autosuggest works", {
 
   # Test with API response mock
   with_mock(
-    "hereR:::.get_content" = function(url) {
+    "hereR:::.async_request" = function(url, rps) {
       hereR:::mock$autosuggest_response
     },
     suggestion <- autosuggest(address = poi$city),
