@@ -7,7 +7,7 @@ test_that("weather observation works", {
 
   # Test with API response mock
   with_mock(
-    "hereR:::.get_content" = function(url) {
+    "hereR:::.async_request" = function(url, rps) {
       hereR:::mock$weather_observation_response
     },
     weather_observation <- weather(poi = poi, product = "observation"),
